@@ -1,11 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mindstream" "1.0"
+(define-package "mindstream" "2.0"
   "Start writing, stay focused, don't worry."
-  '((emacs "25.1")
-    (magit "3.3.0"))
+  '((emacs "28.1"))
   :url "https://github.com/countvajhula/mindstream"
-  :commit "f95e7fc2c6d529533709ae63a55e8ace9287ec0b"
-  :revdesc "v1.0-0-gf95e7fc2c6d5"
+  :commit "6b51036a069379d18538a7cca5274c21666a5979"
+  :revdesc "v2.0-0-g6b51036a0693"
   :keywords '("convenience" "files" "languages" "outlines" "tools" "vc" "wp")
   :authors '(("Siddhartha Kasivajhula" . "sid@countvajhula.com"))
   :maintainers '(("Siddhartha Kasivajhula" . "sid@countvajhula.com")))
